@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use SOAP::Lite;
 
-our $VERSION = '0.302';
+our $VERSION = '0.303';
 $VERSION = eval $VERSION;
 
-use base qw( SOAP::Deserializer );
+our @ISA = qw( SOAP::Deserializer );
 use strict 'refs';
 
 our $XSD_NSPREFIX     = "xsd";
